@@ -17,41 +17,90 @@ sub new {
     return $self;
 }
 
+sub abstract {
+    return 'Download satellite orbital elements from Space Track';
+}
+
+sub add_to_cleanup {
+    return [ qw{ cover_db xt/author/optionals } ];
+}
+
+sub author {
+    return 'Tom Wyant (wyant at cpan dot org)';
+}
+
 sub build_requires {
     return +{
 	'File::Temp'	=> 0,
 ##	'Test::More'	=> 0.40,
 ##	'Test::More'	=> 0.88,	# Because of done_testing().
 	'Test::More'	=> 0.96,	# Because of subtest()
+	lib		=> 0,
     };
 }
 
+sub configure_requires {
+    return +{
+	'Config'	=> 0,
+	'FileHandle'	=> 0,
+	'Getopt::Std'	=> 0,
+	'lib'	=> 0,
+	'strict'	=> 0,
+	'warnings'	=> 0,
+    };
+}
+
+sub dist_name {
+    return 'Astro-SpaceTrack';
+}
+
 sub distribution {
     my ( $self ) = @_;
     return $self->{distribution};
 }
 
+
+sub license {
+    return 'perl';
+}
+
 sub meta_merge {
+    my ( undef, @extra ) = @_;
     return {
 	'meta-spec'	=> {
 	    version	=> 2,
 	},
 	dynamic_config	=> 1,
-	no_index	=> {
-	    directory	=> [ qw{ inc t tools xt } ],
-	},
 	resources	=> {
 	    bugtracker	=> {
-		web	=> 'https://github.com/trwyant/perl-Astro-SpaceTrack/issues',
-		mailto	=> 'wyant@cpan.org',
-            },
+		web	=> 'https://rt.cpan.org/Public/Dist/Display.html?Name=Astro-SpaceTrack',
+		# web	=> 'https://github.com/trwyant/perl-Astro-SpaceTrack/issues',
+		mailto  => 'wyant@cpan.org',
+	    },
 	    license	=> 'http://dev.perl.org/licenses/',
 	    repository	=> {
 		type	=> 'git',
 		url	=> 'git://github.com/trwyant/perl-Astro-SpaceTrack.git',
 		web	=> 'https://github.com/trwyant/perl-Astro-SpaceTrack',
 	    },
-	}
+	},
+	@extra,
+    };
+}
+
+
+sub module_name {
+    return 'Astro::SpaceTrack';
+}
+
+sub no_index {
+    return +{
+      directory => [
+                     'inc',
+                     't',
+                     'tools',
+                     'xt',
+                   ],
     };
 }
 
@@ -85,12 +134,44 @@ EOD
     }
 }
 
+sub provides {
+    -d 'lib'
+	or return;
+    local $@ = undef;
+    my $provides = eval {
+	require Module::Metadata;
+	Module::Metadata->provides( version => 2, dir => 'lib' );
+    } or return;
+
+    eval {
+	require CPAN::Meta;
+	# Skeleton so we can use should_index_file() and
+	# should_index_package().
+	my $meta = CPAN::Meta->new( {
+		name	=> 'Euler',
+		version	=> 2.71828,
+		no_index	=> no_index(),
+	    },
+	);
+	foreach my $pkg ( keys %{ $provides } ) {
+	    $meta->should_index_package( $pkg )
+		and $meta->should_index_file( $provides->{$pkg}{file} )
+		and next;
+	    delete $provides->{$pkg};
+	}
+
+	1;
+    } or return;
+
+    return ( provides => $provides );
+}
+
 sub requires {
     my ( undef, @extra ) = @_;		# Invocant unused
 
     return {
 	'Carp'			=> 0,
-	'Data::Dumper'		=> 0,
+	'Config'		=> 0,
 	'Exporter'		=> 0,
 	'Getopt::Long'		=> 2.39,	# For getoptionsfromarray
 	'HTTP::Date'		=> 0,
@@ -127,6 +208,16 @@ sub requires_perl {
 }
 
 
+sub script_files {
+    return [
+	'script/SpaceTrack',
+    ];
+}
+
+sub version_from {
+    return 'lib/Astro/SpaceTrack.pm';
+}
+
 1;
 
 __END__
@@ -161,6 +252,19 @@ This class supports the following public methods:
 
 This method instantiates the class.
 
+=head2 abstract
+
+This method returns the distribution's abstract.
+
+=head2 add_to_cleanup
+
+This method returns a reference to an array of files to be added to the
+cleanup.
+
+=head2 author
+
+This method returns the name of the distribution author
+
 =head2 build_requires
 
  use JSON;
@@ -171,6 +275,20 @@ modules required to build the C<Astro::Coord::ECI> package, suitable for
 use in a F<Build.PL> C<build_requires> key, or a F<Makefile.PL>
 C<< {META_MERGE}->{build_requires} >> key.
 
+=head2 configure_requires
+
+ use YAML;
+ print Dump( $meta->configure_requires() );
+
+This method returns a reference to a hash describing the modules
+required to configure the package, suitable for use in a F<Build.PL>
+C<configure_requires> key, or a F<Makefile.PL>
+C<< {META_MERGE}->{configure_requires} >> or C<CONFIGURE_REQUIRES> key.
+
+=head2 dist_name
+
+This method returns the distribution name.
+
 =head2 distribution
 
  if ( $meta->distribution() ) {
@@ -182,6 +300,10 @@ C<< {META_MERGE}->{build_requires} >> key.
 This method returns the value of the environment variable
 C<MAKING_MODULE_DISTRIBUTION> at the time the object was instantiated.
 
+=head2 license
+
+This method returns the distribution's license.
+
 =head2 meta_merge
 
  use YAML;
@@ -189,8 +311,20 @@ C<MAKING_MODULE_DISTRIBUTION> at the time the object was instantiated.
 
 This method returns a reference to a hash describing the meta-data which
 has to be provided by making use of the builder's C<meta_merge>
-functionality. This includes the C<dynamic_config>, C<no_index> and
-C<resources> data.
+functionality. This includes the C<dynamic_config> and C<resources>
+data.
+
+Any arguments will be appended to the generated array.
+
+=head2 module_name
+
+This method returns the name of the module the distribution is based
+on.
+
+=head2 no_index
+
+This method returns the names of things which are not to be indexed
+by CPAN.
 
 =head2 notice
 
@@ -201,6 +335,16 @@ executables to build.
 
 The argument is the options hash returned by the build system.
 
+=head2 provides
+
+ use YAML;
+ print Dump( [ $meta->provides() ] );
+
+This method attempts to load L<Module::Metadata|Module::Metadata>. If
+this succeeds, it returns a C<provides> entry suitable for inclusion in
+L<meta_merge()|/meta_merge> data (i.e. C<'provides'> followed by a hash
+reference). If it can not load the required module, it returns nothing.
+
 =head2 requires
 
  use JSON;
@@ -219,6 +363,16 @@ configuration-specific modules may be added.
 
 This method returns the version of Perl required by the package.
 
+=head2 script_files
+
+This method returns a reference to an array containing the names of
+script files provided by this distribution. This array may be empty.
+
+=head2 version_from
+
+This method returns the name of the distribution file from which the
+distribution's version is to be derived.
+
 =head1 ATTRIBUTES
 
 This class has no public attributes.
@@ -236,7 +390,9 @@ information makes it into F<META.yml>.
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<http://rt.cpan.org>, or in electronic mail to the author.
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=Astro-SpaceTrack>,
+L<https://github.com/trwyant/perl-Astro-SpaceTrack/issues/>, or in
+electronic mail to the author.
 
 =head1 AUTHOR
 
